@@ -6,7 +6,7 @@
 
 
 TEST_CASE("MetricsCollector basics", "[metrics/collector]") {
-    MetricsCollector collector("Test collector", "human", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", "test.bam");
+    MetricsCollector collector("Test collector", "human", "", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", "test.bam");
 
     SECTION("MetricsCollector::is_autosomal") {
         REQUIRE(collector.is_autosomal("chr1"));
@@ -26,7 +26,8 @@ TEST_CASE("MetricsCollector basics", "[metrics/collector]") {
             "Operating parameters\n" +
             "====================\n" +
             "Thread limit: 1\n" +
-            "Ignoring read groups: no\n\n" +
+            "Ignoring read groups: no\n" +
+            "Is single nucleus: no\n\n" +
             "Experiment information\n" +
             "======================\n" +
             "Organism: human\n" +
@@ -63,7 +64,7 @@ TEST_CASE("MetricsCollector::test_supplied_references", "[metrics/test_supplied_
         *out << "I\nII\nIII\n";
     }
 
-    MetricsCollector collector("Test collector", "human", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", "test.bam", autosomal_reference_file, "M", "", "", 1000, true, false);
+    MetricsCollector collector("Test collector", "human", "", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", "test.bam", autosomal_reference_file, "M", "", "", 1000, true, false, false);
 
     std::remove(autosomal_reference_file.c_str());
 
@@ -82,7 +83,7 @@ TEST_CASE("MetricsCollector::test_supplied_references", "[metrics/test_supplied_
     }
 
     SECTION("Bad autosomal reference file") {
-        REQUIRE_THROWS(MetricsCollector badcollector("Test collector", "human", "a collector with a bad autosomal reference file", "a library of brutal tests?", "https://theparkerlab.org", "test.bam", "bad_autosomal_reference_file.txt"));
+        REQUIRE_THROWS(MetricsCollector badcollector("Test collector", "human", "", "a collector with a bad autosomal reference file", "a library of brutal tests?", "https://theparkerlab.org", "test.bam", "bad_autosomal_reference_file.txt"));
     }
 }
 
@@ -92,7 +93,7 @@ TEST_CASE("Metrics::load_alignments with no excluded regions", "[metrics/load_al
     std::string alignment_file_name("SRR891275.bam");
     std::string peak_file_name("SRR891275.peaks.gz");
 
-    MetricsCollector collector(name, "human", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, "", true, false);
+    MetricsCollector collector(name, "human", "", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, "", true, false, false);
 
     collector.load_alignments();
 
@@ -108,7 +109,7 @@ TEST_CASE("Metrics::load_alignments", "[metrics/load_alignments]") {
     std::string peak_file_name("test.peaks.gz");
     std::string tss_file_name("hg19.tss.refseq.bed.gz");
 
-    MetricsCollector collector(name, "human", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, tss_file_name, 1000, true, 1, false, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
+    MetricsCollector collector(name, "human", "", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, tss_file_name, 1000, true, 1, false, false, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
 
     collector.load_alignments();
 
@@ -168,12 +169,12 @@ TEST_CASE("Metrics::load_alignments", "[metrics/load_alignments]") {
 
 TEST_CASE("Metrics::load_alignments errors", "[metrics/load_alignments_errors]") {
     SECTION("MetricsCollector::load_alignments fails without alignment file name") {
-        MetricsCollector collector("Broken collector", "human", "a collector without an alignment file", "a library of brutal tests?", "https://theparkerlab.org", "", "", "", "");
+        MetricsCollector collector("Broken collector", "human", "", "a collector without an alignment file", "a library of brutal tests?", "https://theparkerlab.org", "", "", "", "");
         REQUIRE_THROWS_AS(collector.load_alignments(), FileException);
     }
 
     SECTION("MetricsCollector::load_alignments fails with bad alignment file name") {
-        MetricsCollector collector("Broken collector", "human", "a collector with a non-existent alignment file", "a library of brutal tests?", "https://theparkerlab.org", "missing_alignment_file.bam", "", "chrM", "");
+        MetricsCollector collector("Broken collector", "human", "", "a collector with a non-existent alignment file", "a library of brutal tests?", "https://theparkerlab.org", "missing_alignment_file.bam", "", "chrM", "");
         REQUIRE_THROWS_AS(collector.load_alignments(), FileException);
     }
 }
@@ -183,7 +184,7 @@ TEST_CASE("Metrics::ignore_read_groups", "[metrics/ignore_read_groups]") {
     std::string alignment_file_name("test.bam");
     std::string peak_file_name("test.peaks.gz");
 
-    MetricsCollector collector(name, "human", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, "", 1000, true, 1, true, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
+    MetricsCollector collector(name, "human", "", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, "", 1000, true, 1, true, false, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
 
     collector.load_alignments();
 
@@ -244,7 +245,7 @@ TEST_CASE("Metrics::missing_peak_file", "[metrics/missing_peak_file]") {
     std::string alignment_file_name("test.bam");
     std::string peak_file_name("notthere.peaks.gz");
 
-    MetricsCollector collector(name, "human", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, "", 1000, true, 1, true, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
+    MetricsCollector collector(name, "human", "", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, "", 1000, true, 1, true, false, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
     REQUIRE_THROWS_AS(collector.load_alignments(), FileException);
 }
 
@@ -254,6 +255,6 @@ TEST_CASE("Metrics::missing_tss_file", "[metrics/missing_ss_file]") {
     std::string peak_file_name("test.peaks.gz");
     std::string tss_file_name("notthere.bed.gz");
 
-    MetricsCollector collector(name, "human", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, tss_file_name, 1000, true, 1, true, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
+    MetricsCollector collector(name, "human", "", "a collector for unit tests", "a library of brutal tests?", "https://theparkerlab.org", alignment_file_name, "", "chrM", peak_file_name, tss_file_name, 1000, true, 1, true, false, true, false, {"exclude.dac.bed.gz", "exclude.duke.bed.gz"});
     REQUIRE_THROWS_AS(collector.load_alignments(), FileException);
 }
